==> haskell-mime-mail-0.5.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mime-mail.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mime-mail
version: 0.5.0
id: mime-mail-0.5.0-Fr2vVA1bd1gIwhTYhwJXXp
key: mime-mail-0.5.0-Fr2vVA1bd1gIwhTYhwJXXp
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Marek Suchánek <marek.suchanek@fit.cvut.cz>
author: Michael Snoyman <michael@snoyman.com>
homepage: http://github.com/snoyberg/mime-mail
synopsis: Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.
category: Email
abi: d23f4be8329bda9c14c4f5bf38275afd
exposed: True
exposed-modules:
    Network.Mail.Mime
import-dirs: /usr/lib/ghc-8.6.5/site-local/mime-mail-0.5.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/mime-mail-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mime-mail-0.5.0
hs-libraries: HSmime-mail-0.5.0-Fr2vVA1bd1gIwhTYhwJXXp
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-4mGTJNwsUu7LJDOWBfkS70
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    filepath-1.4.2.1 process-1.6.5.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html: /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mime-mail-0.5.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mime-mail.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mime-mail
version: 0.5.0
id: mime-mail-0.5.0-Lu2LwvenEGs5kBTEd05zlQ
key: mime-mail-0.5.0-Lu2LwvenEGs5kBTEd05zlQ
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Marek Suchánek <marek.suchanek@fit.cvut.cz>
author: Michael Snoyman <michael@snoyman.com>
homepage: http://github.com/snoyberg/mime-mail
synopsis: Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.
category: Email
abi: 129a8e74f63be306698844125fee787c
exposed: True
exposed-modules:
    Network.Mail.Mime
import-dirs: /usr/lib/ghc-8.6.5/site-local/mime-mail-0.5.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/mime-mail-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mime-mail-0.5.0
hs-libraries: HSmime-mail-0.5.0-Lu2LwvenEGs5kBTEd05zlQ
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-Isuu0DM5i6LOS2qIIf24
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    filepath-1.4.2.1 process-1.6.5.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html: /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
